@@ -44,6 +44,10 @@ class SlapPipe:
         if self.slapp_process:
             self.slapp_loop = False
             self.slapp_write_queue.put_nowait('')
+            logging.info('stopping pipes')
+            self.slapp_process.stdin.close()
+            self.slapp_process.stderr.feed_eof()
+            self.slapp_process.stdout.feed_eof()
             logging.info('killing process')
             self.slapp_process.kill()
             self.slapp_process = None
@@ -98,7 +102,7 @@ class SlapPipe:
                     else:
                         logging.info(f'_write_stdin: exiting')
                         return
-                await asyncio.sleep(1)
+                await asyncio.sleep(1)  # 1 sec yield
             except Exception as e:
                 logging.error(f'_write_stdin EXCEPTION: {traceback.format_exc()}', exc_info=e)
 
